@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2019 the original author or authors.
+ * Copyright 2006-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -41,13 +41,13 @@ public class JspReporter implements Reporter {
 
    private static class Result {
 
-      Candidate candidate;
+      final Candidate candidate;
 
-      Candidate.CandidateType type;
+      final Candidate.CandidateType type;
 
-      boolean result;
+      final boolean result;
 
-      Exception exception;
+      final Exception exception;
 
       /**
        * @param candidate Candidate tested
@@ -207,7 +207,7 @@ public class JspReporter implements Reporter {
 
          log.println();
 
-         summary.println("<p>--- FAILED: " + errorCount + " error(s) occured ---</p>");
+         summary.println("<p>--- FAILED: " + errorCount + " error(s) occurred ---</p>");
       }
       else {
          summary.println("<p>--- SUCCESSFUL: TCK tests passed without errors in " + totalTime + " ms</p>");
