@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2018 the original author or authors.
+ * Copyright 2006-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,7 +32,7 @@ public class JspWriterListener implements SearchWorkingInstantiatorListener {
 
    private static final String PATTERN = "<tr><td>%s</td><td>%s</td></tr>";
 
-   private JspWriter writer;
+   private final JspWriter writer;
 
    public JspWriterListener(JspWriter out) {
       this.writer = out;
@@ -50,7 +50,7 @@ public class JspWriterListener implements SearchWorkingInstantiatorListener {
       ByteArrayOutputStream b = new ByteArrayOutputStream();
       t.printStackTrace(new PrintStream(b));
       try {
-         writer.println(String.format(PATTERN, c.getSimpleName() + " (" + getTypology(c) + ")", "KO - " + b.toString()));
+         writer.println(String.format(PATTERN, c.getSimpleName() + " (" + getTypology(c) + ")", "KO - " + b));
       } catch (IOException e) {
          throw new RuntimeException(e);
       }
