@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2019 the original author or authors.
+ * Copyright 2006-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -37,7 +37,7 @@ public class ConstructorInstantiator<T> implements ObjectInstantiator<T> {
 
    public ConstructorInstantiator(Class<T> type) {
       try {
-         constructor = type.getDeclaredConstructor((Class[]) null);
+         constructor = type.getDeclaredConstructor((Class<?>[]) null);
       }
       catch(Exception e) {
          throw new ObjenesisException(e);
