@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2019 the original author or authors.
+ * Copyright 2006-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,7 +29,7 @@ import java.lang.reflect.InvocationTargetException;
  */
 public class SingleInstantiatorStrategy implements InstantiatorStrategy {
 
-   private Constructor<?> constructor;
+   private final Constructor<?> constructor;
 
    /**
     * Create a strategy that will return always the same instantiator type. We assume this instantiator
