@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2019 the original author or authors.
+ * Copyright 2006-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,11 +30,8 @@ public class SerializingInstantiatorTest {
    @Test
    public void testNotSerializable() {
       ObjenesisSerializer o = new ObjenesisSerializer();
-      try {
-    	  o.newInstance(Object.class);
-    	  fail("Should have thrown an exception");
-      } catch (ObjenesisException e) {
-    	  assertTrue(e.getCause() instanceof NotSerializableException);
-      }
+      ObjenesisException exception = assertThrows(ObjenesisException.class, () -> o.newInstance(Object.class));
+      assertEquals(exception.getCause().getClass(), NotSerializableException.class);
    }
+
 }
