@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2018 the original author or authors.
+ * Copyright 2006-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -70,7 +70,7 @@ public class ObjenesisTest extends AndroidTestCase {
    }
 
    @SmallTest
-   public void testObjenesis() throws Exception {
+   public void testObjenesis() {
       TCK tck = new TCK(new ObjenesisStd(), new ObjenesisSerializer(), new JUnitReporter());
       tck.runTests();
    }
