@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2019 the original author or authors.
+ * Copyright 2006-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -91,13 +91,7 @@ public class AbstractLoaderTest {
 
    @Test
    public void testThrowsIOExceptionIfResourceNotInClassPath() {
-      try {
-         loader.loadFromResource( "Blatantly-Bogus.properties", Candidate.CandidateType.STANDARD);
-         fail("Expected exception");
-      }
-      catch(IOException expectedException) {
-         // Good!
-      }
+      assertThrows(IOException.class, () -> loader.loadFromResource( "Blatantly-Bogus.properties", Candidate.CandidateType.STANDARD));
    }
 
    // Sample classes.
